@@ -7,6 +7,10 @@ from django.views.decorators.csrf import csrf_exempt
 import json
 from django.utils import timezone
 from custom.utils import getnewid, getjustnewid, hash_md5, getlastid
+
+from population.utils import getlastid_kinos,getlastid_kinosrp
+
+
 from population.utils import createnewid
 from django.db.models import Count
 from django.contrib import messages
@@ -52,7 +56,6 @@ def dashboard_population(request):
     userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
     tinan = timezone.now().strftime("%Y")
 
-
     # totalpop  = Population.objects.filter(Q(date_register__year = tinan) & Q(village__id  = userAddress.employee.village.id) & Q(status_datap = 'ac') & Q(type_data = 'f') & Q(id_family = 'i')).count()
     totalpop  = DetailFamily.objects.filter(Q(population__date_register__year = tinan) & Q(population__village__id  = userAddress.employee.village.id) & Q(population__status_datap = 'ac') & Q(population__type_data = 'f') & Q(status = True) & Q(population__id_family = 'i')).count()
     
@@ -150,8 +153,8 @@ def family_list(request):
 def family_input(request):
 
     userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
+    
     idfamilia = getnewidf()
-
     idfmlast = 0
 
     try:
@@ -164,13 +167,12 @@ def family_input(request):
   
 
 
-
-
     if request.POST :
-        _, newid = getlastid(Family)
-        hashid = hash_md5(str(newid))
-        # id = str(userAddress.employee.village.id)+str(newid) 
-        id = newid
+
+        id = getlastid_kinos(Family,str(userAddress.employee.village.id))
+        hashid = hash_md5(str(id))
+
+
 
         village = Village.objects.get(id=userAddress.employee.village.id)
         dataagora = timezone.now()
@@ -490,21 +492,39 @@ def familymember_input(request, hashed):
 
     if request.POST :
 
-        _, newid = getlastid(Population)
-        # id = str(userAddress.employee.village.id)+str(newid) 
-        id = newid
-        hashid = hash_md5(str(newid))
+        # _, newid = getlastid(Population)
+        # # id = str(userAddress.employee.village.id)+str(newid) 
+        # id = newid
+        # hashid = hash_md5(str(newid))
+
+
+
+        id = getlastid_kinos(Population,str(userAddress.employee.village.id))
+        hashid = hash_md5(str(id))
+
+
+        # _, newidf = getlastid(DetailFamily)
+        # # idf = str(userAddress.employee.village.id)+str(newidf) 
+        # idf = newidf
+        # hashidf = hash_md5(str(newidf))
+
+        # idf = getlastid_kinos_df(DetailFamily,str(userAddress.employee.village.id))
+        # hashidf = hash_md5(str(idf))
+
+        idf = getlastid_kinosrp(DetailFamily,str(userAddress.employee.village.id))
+        hashidf = hash_md5(str(idf))
+
+
 
-        _, newidf = getlastid(DetailFamily)
-        # idf = str(userAddress.employee.village.id)+str(newidf) 
-        idf = newidf
-        hashidf = hash_md5(str(newidf))
     
 
-        _, newidm = getlastid(Migration)
-        # idm = str(userAddress.employee.village.id)+str(newidm) 
-        idm = newidm
-        hashidm = hash_md5(str(newidm))
+        # _, newidm = getlastid(Migration)
+        # # idm = str(userAddress.employee.village.id)+str(newidm) 
+        # idm = newidm
+        # hashidm = hash_md5(str(newidm))
+
+        idm = getlastid_kinos(Migration,str(userAddress.employee.village.id))
+        hashidm = hash_md5(str(idm))
     
 
 
@@ -790,29 +810,40 @@ def familymember_out(request,hashed):
 
     if request.POST :
         if request.POST['prosses'] == 'input' :
-            _, newidd = getlastid(Migrationout)
+            # _, newidd = getlastid(Migrationout)
             # idd = str(userAddress.employee.village.id)+str(newidd) 
-            idd = newidd
-            hashid = hash_md5(str(newidd))
-            form = Migrationout_form(userAddress.employee.village.id,request.POST)
-            if form.is_valid() :
-                instance = form.save(commit=False)
-                instance.id = idd
-                instance.population = pophash
-                instance.user_created = request.user
-                instance.date_created = dataagora
-                instance.hashed = hashid
-                instance.village = village
-                instance.save()
-                
-                populasaun = get_object_or_404(Population, id= detailfamdata.population.id)
-                populasaun.status_datap = 'mu'
-                populasaun.save()
+            # idd = newidd
 
-                dfam = get_object_or_404(DetailFamily, id= detailfamdata.id)
-                dfam.status = False
-                dfam.save()
-                messages.success(request,'Dadus Rejitu Ho susesu !')
+            idd = getlastid_kinos(Migrationout,str(userAddress.employee.village.id))
+            hashid = hash_md5(str(idd))
+
+
+            # hashid = hash_md5(str(newidd))
+
+
+            form = Migrationout_form(userAddress.employee.village.id,request.POST)
+            cekmuda = Migrationout.objects.filter(population=pophash.id).count()
+            if cekmuda == 0 :
+                if form.is_valid() :
+                    instance = form.save(commit=False)
+                    instance.id = idd
+                    instance.population = pophash
+                    instance.user_created = request.user
+                    instance.date_created = dataagora
+                    instance.hashed = hashid
+                    instance.village = village
+                    instance.save()
+                    
+                    populasaun = get_object_or_404(Population, id= detailfamdata.population.id)
+                    populasaun.status_datap = 'mu'
+                    populasaun.save()
+
+                    dfam = get_object_or_404(DetailFamily, id= detailfamdata.id)
+                    dfam.status = False
+                    dfam.save()
+                    messages.success(request,'Dadus Rejitu Ho susesu !')
+                    return redirect('population:detailfamily_list', hashed = familiaid.hashed)
+            else :
                 return redirect('population:detailfamily_list', hashed = familiaid.hashed)
 
         elif request.POST['prosses'] == 'edit' :
@@ -860,31 +891,44 @@ def familymember_mate(request,hashed):
 
     if request.POST :
         if request.POST['prosses'] == 'input' :
-            _, newidd = getlastid(Death)
+
+
+            # _, newidd = getlastid(Death)
             # idd = str(userAddress.employee.village.id)+str(newidd) 
-            idd = newidd
-            hashid = hash_md5(str(newidd))
+            # idd = newidd
+
+            idd = getlastid_kinos(Death,str(userAddress.employee.village.id))
+            hashid = hash_md5(str(idd))
+
+            # hashid = hash_md5(str(newidd))
             form = Death_form(request.POST)
-            if form.is_valid() :
-                instance = form.save(commit=False)
-                instance.id = idd
-                instance.population = pophash
-                instance.user_created = request.user
-                instance.date_created = dataagora
-                instance.hashed = hashid
-                instance.village = village
-                instance.save()
 
-                populasaun = get_object_or_404(Population, id= detailfamdata.population.id)
-                populasaun.status_datap = 'ma'
-                populasaun.save()
+            cekmate = Death.objects.filter(population=pophash.id).count()
 
-                dfam = get_object_or_404(DetailFamily, id= detailfamdata.id)
-                dfam.status = False
-                dfam.save()
+            if cekmate == 0 :
+                if form.is_valid() :
+                    instance = form.save(commit=False)
+                    instance.id = idd
+                    instance.population = pophash
+                    instance.user_created = request.user
+                    instance.date_created = dataagora
+                    instance.hashed = hashid
+                    instance.village = village
+                    instance.save()
+
+                    populasaun = get_object_or_404(Population, id= detailfamdata.population.id)
+                    populasaun.status_datap = 'ma'
+                    populasaun.save()
+
+                    dfam = get_object_or_404(DetailFamily, id= detailfamdata.id)
+                    dfam.status = False
+                    dfam.save()
+
+                    messages.success(request,'Dadus Rejitu Ho susesu !')
+                    return redirect('population:detailfamily_list', hashed = familiaid.hashed)
+            else : 
+                    return redirect('population:detailfamily_list', hashed = familiaid.hashed)
 
-                messages.success(request,'Dadus Rejitu Ho susesu !')
-                return redirect('population:detailfamily_list', hashed = familiaid.hashed)
 
         elif request.POST['prosses'] == 'edit' :
             datamate = Death.objects.get(population = detailfamdata.population.id)
@@ -927,11 +971,18 @@ def familymember_change(request,hashed):
 
     if request.POST :
         if request.POST['prosses'] == 'input' :
-            _, newidd = getlastid(ChangeFamily)
+            # _, newidd = getlastid(ChangeFamily)
             # idc = str(userAddress.employee.village.id)+str(newidd) 
-            idc = newidd
-            hashid = hash_md5(str(newidd))
+            # idc = newidd
+
+            idc = getlastid_kinos(ChangeFamily,str(userAddress.employee.village.id))
+            hashid = hash_md5(str(idc))
+
+
+            # hashid = hash_md5(str(newidd))
+
             form = Changefamily_form(request.POST)
+
             if form.is_valid() :
                 instance = form.save(commit=False)
                 instance.id = idc
